<?php

class Class_Pi_Edd_Design{

    public $plugin_name;

    private $setting = array();

    private $active_tab;

    private $this_tab = 'design';

    private $tab_name = "Design";

    private $setting_key = 'design_settting';


    function __construct($plugin_name){
        $this->plugin_name = $plugin_name;
        
        $this->active_tab = (isset($_GET['tab'])) ? sanitize_text_field($_GET['tab']) : 'default';

        if($this->this_tab == $this->active_tab){
            add_action($this->plugin_name.'_tab_content', array($this,'tab_content'));
        }

        add_action($this->plugin_name.'_tab', array($this,'tab'),3);

        add_action('woocommerce_init', array($this,'shipping_zone_to_array'));
        
        add_action( 'wp_enqueue_scripts', array($this,'register_plugin_styles') );
        
    }

    function register_plugin_styles(){
        wp_register_style( 'dummy-handle', false );
        wp_enqueue_style( 'dummy-handle' );

        $padding_x = 5;
        $padding_y = 5;

        $css = '
            .pi-edd{
                text-align:center;
                margin-top:5px;
                margin-bottom:5px;
                font-size:12px;
                border-radius:6px;
            }

            .pi-edd span{
                font-weight:bold;
            }

            .pi-edd-product{
                background:'.get_option('pi_product_bg_color','#f0947e;').';
                color:'.get_option('pi_product_text_color','#ffffff').';
                padding: '.$padding_y.'px '.$padding_x.'px;
                margin-top:1rem;
                margin-bottom:1rem;
                clear:both;
            }

            .pi-edd-loop{
                background:'.get_option('pi_loop_bg_color','#f0947e;').';
                color:'.get_option('pi_loop_text_color','#ffffff').';
                padding: '.$padding_y.'px '.$padding_x.'px;
            }

            .pi-edd-cart{
                background:'.get_option('pi_cart_bg_color','#f0947e;').';
                color:'.get_option('pi_cart_text_color','#ffffff').';
                padding: '.$padding_y.'px '.$padding_x.'px;
                text-align:left;
                display:inline-block;
                padding:0px 10px;
            }
        ';
        

        wp_add_inline_style( 'dummy-handle', $css );
    }

    function shipping_zone_to_array(){
      
        $this->settings = array(
            array('field'=>'title', 'class'=> 'bg-primary text-light', 'class_title'=>'text-light font-weight-light h4', 'label'=>"Single product page design", 'type'=>"setting_category"),
            array('field'=>'pi_product_bg_color', 'label'=>__('Background color of message','pi-edd'),'type'=>'color', 'default'=>'#f0947e',   'desc'=>'Background color'),
            array('field'=>'pi_product_text_color', 'label'=>__('Text color of message','pi-edd'),'type'=>'color', 'default'=>'#fff',  'desc'=>'Text color'),
            
            
            array('field'=>'title', 'class'=> 'bg-primary text-light', 'class_title'=>'text-light font-weight-light h4', 'label'=>"Shop / Category page design", 'type'=>"setting_category"),
            array('field'=>'pi_loop_bg_color', 'label'=>__('Background color of message','pi-edd'),'type'=>'color', 'default'=>'#f0947e',   'desc'=>'Background color'),
            array('field'=>'pi_loop_text_color', 'label'=>__('Text color of message','pi-edd'),'type'=>'color', 'default'=>'#fff',  'desc'=>'Text color'),


            
            array('field'=>'title', 'class'=> 'bg-primary text-light', 'class_title'=>'text-light font-weight-light h4', 'label'=>"Cart / Checkout page design", 'type'=>"setting_category"),
            array('field'=>'pi_cart_bg_color', 'label'=>__('Background color of message','pi-edd'),'type'=>'color', 'default'=>'#f0947e',   'desc'=>'Background color'),
            array('field'=>'pi_cart_text_color', 'label'=>__('Text color of message','pi-edd'),'type'=>'color', 'default'=>'#ffffff',  'desc'=>'Text color'),
           
           
        );
        $this->register_settings();

        if(PISOL_EDD_DELETE_SETTING){
            $this->delete_settings();
        }
    }

    
    function delete_settings(){
        foreach($this->settings as $setting){
            delete_option( $setting['field'] );
        }
    }


    function register_settings(){   

        foreach($this->settings as $setting){
            register_setting( $this->setting_key, $setting['field']);
        }
    
    }

    function tab(){
        ?>
        <a class=" px-3 text-light d-flex align-items-center  border-left border-right  <?php echo ($this->active_tab == $this->this_tab ? 'bg-primary' : 'bg-secondary'); ?>" href="<?php echo admin_url( 'admin.php?page='.sanitize_text_field($_GET['page']).'&tab='.$this->this_tab ); ?>">
            <?php _e( $this->tab_name, 'http2-push-content' ); ?> 
        </a>
        <?php
    }

    function tab_content(){
       ?>
        <form method="post" action="options.php"  class="pisol-setting-form">
        <?php settings_fields( $this->setting_key ); ?>
        <?php
            foreach($this->settings as $setting){
                new pisol_class_form_edd($setting, $this->setting_key);
            }
        ?>
        <input type="submit" class="mt-3 btn btn-primary btn-sm" value="Save Option" />
        </form>
       <?php
    }
}

new Class_Pi_Edd_Design($this->plugin_name);