<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       piwebsolution.com
 * @since      1.0.0
 *
 * @package    Pi_Edd
 * @subpackage Pi_Edd/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Pi_Edd
 * @subpackage Pi_Edd/admin
 * @author     PI Websolution <rajeshsingh520@gmail.com>
 */
class Pi_Edd_Pro_Woo {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( ) {
		add_action( 'woocommerce_product_data_tabs', array($this,'productTab') );
		/** Adding order preparation days */
		add_action( 'woocommerce_product_data_panels', array($this,'order_preparation_days') );
		add_action( 'woocommerce_process_product_meta', array($this,'order_preparation_days_save') );

		add_action( 'woocommerce_product_quick_edit_end', array($this, 'quickEditForm'));
		add_action('woocommerce_product_quick_edit_save',array($this, 'quickEditSave'));

		add_filter('manage_product_posts_columns', array($this,'quickEditColumns'));
		add_action('manage_posts_custom_column',  array($this,'quickEditColumnsValue'), 10, 2);

	}

	function productTab($tabs){
        $tabs['pisol_mmq'] = array(
            'label'    => 'Preparation Time',
            'target'   => 'pisol_edd',
            'priority' => 21,
        );
        return $tabs;
	}
	

	function order_preparation_days() {
		echo '<div id="pisol_edd" class="panel woocommerce_options_panel hidden">';
		woocommerce_wp_checkbox( array(
            'label' => __("Disable estimate for this product"), 
            'id' => 'pisol_edd_disable_estimate', 
            'name' => 'pisol_edd_disable_estimate', 
            'description' => __("Check this if you don't want to show estimate date for this particular product")
          ) );
		echo '<div id="pisol-product-preparation-days">';
		echo '<div class="show_if_variable">';
		woocommerce_wp_checkbox( array(
			'label' => __("Use Product variation preparation time"), 
			'id' => 'pisol_edd_use_variation_preparation_time', 
			'name' => 'pisol_edd_use_variation_preparation_time', 
			'description' => __("You can set different preparation time for each of the variation (use only for variable products, that too if you want to set different preparation time for each variation)")
		  ) );
		echo '</div>';
		
			$args = array(
			'id' => 'product_preparation_time',
			'label' => __( 'Product preparation days', 'pi-edd' ),
			'type' => 'number',
			'custom_attributes' => array(
				'step' 	=> '1',
				'min'	=> '0'
			) ,
			'placeholder'=>0,
			'class' => 'form-control',
			'desc_tip' => true,
			'description' => __( 'Enter the number of days it take to prepare this product' ),
			);
			woocommerce_wp_text_input( $args );

			$args2 = array(
				'id' => 'out_of_stock_product_preparation_time',
				'label' => __( 'Extra time added to preparation time (when product goes out of stock)', 'pi-edd' ),
				'type' => 'number',
				'custom_attributes' => array(
					'step' 	=> '1',
					'min'	=> '0'
				) ,
				'placeholder'=>0,
				'class' => 'form-control',
				'desc_tip' => true,
				'description' => __( 'This will be added in the normal product preparation time when product is out of stock and you are allowing back-order ' ),
				);
				woocommerce_wp_text_input( $args2 );

			
		echo '</div>';
		echo '</div>';
	}

	   function order_preparation_days_save( $post_id ) {
			$product = wc_get_product( $post_id );
			$value = (int)((isset( $_POST['product_preparation_time'] ) && $_POST['product_preparation_time'] >= 0) ? $_POST['product_preparation_time'] : 0);
			$return = $product->update_meta_data( 'product_preparation_time', sanitize_text_field( $value ) );

			$out_of_stock_product_preparation_time = (int)((isset( $_POST['out_of_stock_product_preparation_time'] ) && $_POST['out_of_stock_product_preparation_time'] >= 0) ? $_POST['out_of_stock_product_preparation_time'] : 0);
			if ( isset( $out_of_stock_product_preparation_time ) ){
				$product->update_meta_data( 'out_of_stock_product_preparation_time', esc_attr( $out_of_stock_product_preparation_time ) );
			}else{
				$product->update_meta_data( 'out_of_stock_product_preparation_time',0 );
			}

			$disable_estimate = isset($_POST['pisol_edd_disable_estimate']) ? 'yes' : 'no';
			$product->update_meta_data( 'pisol_edd_disable_estimate', $disable_estimate );

			$use_variation_days = isset($_POST['pisol_edd_use_variation_preparation_time']) ? 'yes' : 'no';
			$product->update_meta_data( 'pisol_edd_use_variation_preparation_time', $use_variation_days );

			$product->save();
	   }
	   
	   function quickEditForm(){
		$args = array(
			'id' => 'product_preparation_time',
			'label' => __( 'Product preparation time', 'pi-edd' ),
			'type' => 'number',
			'custom_attributes' => array(
				'step' 	=> '1',
				'min'	=> '0'
			) ,
			'placeholder'=>0,
			'class' => 'form-control',
			'desc_tip' => false,
			'description' => __( 'Enter the number of days it take to prepare this product' ),
			);
			
		?>
		<div class="inline-edit-col">
			<label class="alignleft">
				<?php woocommerce_wp_text_input( $args ); ?>
			</label>
		</div>
		<?php
	   }

	   function quickEditSave($product){

				$post_id = $product->get_id();
			
				if ( isset( $_REQUEST['product_preparation_time'] ) ) {
			
					$customFieldDemo = trim(esc_attr( $_REQUEST['product_preparation_time'] ));
			
					// Do sanitation and Validation here
			
					update_post_meta( $post_id, 'product_preparation_time', wc_clean( $customFieldDemo ) );
				}
		
	   }

	   function quickEditColumns( $column_array ) {
 
		$column_array['preparation_time'] = 'Preparation Days';
	 
		return $column_array;
	  }

	  function quickEditColumnsValue( $column_name, $id ) {
		switch( $column_name ) :
			case 'preparation_time': {
				$ppt = get_post_meta( $id, 'product_preparation_time', true );
				echo $ppt == "" ? 0 : $ppt;
				echo '<input type="hidden" id="product_preparation_time_post-'.$id.'" value="'.$ppt.'"/>';
				break;
			}
		endswitch;
	}

}

new Pi_Edd_Pro_Woo();




