<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              piwebsolution.com
 * @since             4.4.4
 * @package           Pi_Edd
 *
 * @wordpress-plugin
 * Plugin Name:       Estimate delivery date for Woocommerce Pro
 * Plugin URI:        https://www.piwebsolution.com/cart/?add-to-cart=879
 * Description:       WooCommerce Estimated delivery date per product, You don't have to set dates in each product, just add it in shipping method, based on shipping days and product preparation days it shows estimated shipping date per product and also considers holidays
 * Version:           4.4.4
 * Author URI:        https://www.piwebsolution.com/
 * Author:            PI Websolution
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       pi-edd
 * Domain Path:       /languages
 * WC tested up to: 3.8.1
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}
include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

/**
 * Checking Pro version
 */
function pi_edd_free_check(){
	if(is_plugin_active( 'estimate-delivery-date-for-woocommerce/pi-edd.php')){
		return true;
	}
	return false;
}

if(pi_edd_free_check()){
    function pi_edd_my_free_notice() {
        ?>
        <div class="error notice">
            <p><?php _e( 'Please uninstall the FREE version of Estimate delivery date for Woocommerce then activate the PRO version', 'pi-edd' ); ?></p>
        </div>
        <?php
    }
    add_action( 'admin_notices', 'pi_edd_my_free_notice' );
    deactivate_plugins(plugin_basename(__FILE__));
    return;
}else{


/* 
    Making sure woocommerce is there 
*/


if(!is_plugin_active( 'woocommerce/woocommerce.php')){
    function pi_edd_pro_woo_error_notice() {
        ?>
        <div class="error notice">
            <p><?php _e( 'Please Install and Activate WooCommerce plugin, without that this plugin cant work', 'pi-edd' ); ?></p>
        </div>
        <?php
    }
    add_action( 'admin_notices', 'pi_edd_pro_woo_error_notice' );
    deactivate_plugins(plugin_basename(__FILE__));
    return;
}




/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'PI_EDD_VERSION', '4.4.4' );
define( 'PISOL_EDD_DELETE_SETTING', false);

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-pi-edd-activator.php
 */
function activate_pi_edd() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-pi-edd-activator.php';
	Pi_Edd_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-pi-edd-deactivator.php
 */
function deactivate_pi_edd() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-pi-edd-deactivator.php';
	Pi_Edd_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_pi_edd' );
register_deactivation_hook( __FILE__, 'deactivate_pi_edd' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-pi-edd.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_pi_edd() {

	$plugin = new Pi_Edd();
	$plugin->run();

}
run_pi_edd();


if ( class_exists( 'Pisol_Support' ) ) {
    new Pisol_Support(array(
        'slug'      => 'estimate-delivery-date-for-woocommerce-pro',
        'version'   => PI_EDD_VERSION,
        'remote_url' => 'https://www.piwebsolution.com/support',
        'site_url'=> get_site_url(),
        'promotion_action'=>"pi-edd_promotion"
    ));
}


}