<?php

class Pi_Edd_Message_Engine{
   
    function __construct($rule){
        $this->rule = $rule;
        $this->msg_template_single_single = $this->messageTemplate('single');
        $this->msg_template_single_range = $this->messageTemplate('single','_range');
        $this->msg_template_loop_single = $this->messageTemplate('loop');
        $this->msg_template_loop_range = $this->messageTemplate('loop','_range');
        $this->msg_template_cart_single = $this->messageTemplate('cart');
        $this->msg_template_cart_range = $this->messageTemplate('cart','_range');

        $this->today  = current_time('Y/m/d');

        if($this->rule->getEnableEstimateForThisProduct()){
            $this->estimate_date = $this->rule->getMinMax() == 'min' ? $this->rule->getMinEstimateDate() : $this->rule->getMaxEstimateDate();

            $this->min_estimate_date = $this->rule->getMinEstimateDate();

            $this->max_estimate_date = $this->rule->getMaxEstimateDate();

            $this->generateMessage();
        }
    }

    function generateMessage(){
        

        if($this->rule->useVariablePreparationTime()){
            $variations = $this->rule->getVariations();
            $message = array();
            foreach($variations as $variation){
                if(self::isInStock($variation['variation_id'])){
                    $message[$variation['variation_id']] = $this->messageMaker($this->getDate($variation['variation_id']), $this->getDateMin($variation['variation_id']), $this->getDateMax($variation['variation_id']));
                }else{
                    $message[$variation['variation_id']] = self::blankMessageArray();
                }
            }
            $this->rule->setCompiledMessage($message);

        }else{
            $message = array();
            
            if(self::isInStock($this->rule->getProductId())){
                $message = $this->messageMaker($this->estimate_date, $this->min_estimate_date, $this->max_estimate_date);
            }else{
                $message = self::blankMessageArray();
            }
            $this->rule->setCompiledMessage($message);
        }
    }

    static function isInStock($product_id){
        $product = wc_get_product($product_id);
        if($product->is_in_stock()){
            return true;
        }
        return false;
    }

    static function blankMessageArray(){
        return array('single'=>"", 
        'single_range'=>"", 
        'loop'=>"", 
        'loop_range'=>"", 
        'cart'=>"", 
        'cart_range'=>"");
    }

    function formatedDate($date){
        if(empty($date)) return null;
        
        return date_i18n($this->rule->getDateFormat(), strtotime($date));
    }

    function getDate($variation_id){
        return $this->estimate_date[$variation_id];
    }
    function getDateMin($variation_id){
        return $this->min_estimate_date[$variation_id];
    }

    function getDateMax($variation_id){
        return $this->max_estimate_date[$variation_id];
    }

    function messageMaker($date, $min_date, $max_date){
        if(empty($min_date) && empty($max_date)) return null;

        $days = self::daysAwayFromToday($date);
        $min_days = self::daysAwayFromToday($min_date);
        $max_days = self::daysAwayFromToday($max_date);

        $date = $this->formatedDate($date);
        $min_date = $this->formatedDate($min_date);
        $max_date = $this->formatedDate($max_date);

        $find = array('{date}','{min_date}','{max_date}','{days}', '{min_days}', '{max_days}');
        $replace = array($date, $min_date, $max_date, $days, $min_days, $max_days);

        $msg['single'] = str_replace($find, $replace, $this->msg_template_single_single);

        if($min_date != $max_date){
            $msg['single_range'] = str_replace($find, $replace, $this->msg_template_single_range);
        }else{
            $msg['single_range'] = str_replace($find, $replace, $this->msg_template_single_single);
        }

        $msg['loop'] = str_replace($find, $replace, $this->msg_template_loop_single);

        if($min_date != $max_date){
            $msg['loop_range'] = str_replace($find, $replace, $this->msg_template_loop_range);
        }else{
            $msg['loop_range']  = str_replace($find, $replace, $this->msg_template_loop_single);
        }
        

        $msg['cart'] = str_replace($find, $replace, $this->msg_template_cart_single);

        if($min_date != $max_date){
            $msg['cart_range'] = str_replace($find, $replace, $this->msg_template_cart_range);
        }else{
            $msg['cart_range'] = str_replace($find, $replace, $this->msg_template_cart_single);
        }

        return $msg;
    }

    function messageTemplate($position, $range = ""){
        $msg = 'msg_tmp_'.$position.$range;
        return $this->rule->getMessageText($msg);  
    }

    static function daysAwayFromToday($estimate){
        $today = current_time("Y/m/d");
        $datetime1 = date_create($today); 
        $datetime2 = date_create($estimate); 
  
        // Calculates the difference between DateTime objects 
        $interval = date_diff($datetime1, $datetime2);
        return $interval->days;
    }

}