<?php

class Pi_Edd_Order_Estimate{

    function __construct($items){
        $this->items = $items;
        $this->date_format = get_option('pi_general_date_format','Y/m/d');
        $this->min_max = get_option('pi_edd_min_max','min');
        $this->range = get_option('pi_general_range',0);
        
        $this->calculate();
    }

    function calculate(){
        $estimate_dates = $this->getEstimateDates();
        $this->min_date = $this->getSmallestDate($estimate_dates);
        $this->max_date = $this->getLargestDate($estimate_dates);
        $this->estimate = $this->max_date;
        $this->msg = $this->message();
    }

    function getEstimateDates(){
        if(empty($this->range)){
            if($this->min_max == 'min'){
                return $this->getEstimates('min');
            }else{
                return $this->getEstimates('max');
            }
        }else{
            return $this->getEstimates('all');
        }
    }

    function getEstimates($get = 'all'){ // min, max ,all
        $estimates = array();
        $all  = array();
        foreach($this->items as $item){
            $rule_obj = new Pi_Edd_Product_Rule($item['product_id'], $item['quantity']);
            
            if($rule_obj->useVariablePreparationTime()){
                    $variation_id = $item['variation_id'];
                    $estimates['min'][] = $rule_obj->getMinEstimateDate($variation_id);
                    $estimates['max'][] = $rule_obj->getMaxEstimateDate($variation_id);
                    $all[] = $rule_obj->getMinEstimateDate($variation_id);
                    $all[] = $rule_obj->getMaxEstimateDate($variation_id);
            }else{
                    $estimates['min'][] = $rule_obj->getMinEstimateDate();
                    $estimates['max'][] = $rule_obj->getMaxEstimateDate();
                    $all[] = $rule_obj->getMinEstimateDate();
                    $all[] = $rule_obj->getMaxEstimateDate();
            }

            
        }

        if($get == 'min'){
            return isset($estimates['min']) ? $estimates['min'] : array();
        }elseif($get == 'max'){
            return isset($estimates['max']) ? $estimates['max'] : array();
        }elseif($get == 'all'){
            return isset($all) ? $all : array();
        }

        return $estimates;
    }

    function getLargestDate($date_array){
        $estimates = $date_array;
        $longest = 0;
        $longestDate = "";
        if(is_array($estimates) && !empty($estimates)){
        foreach($estimates as $key => $date){
            if(!$date) continue;

            $curDate = strtotime($date);
            if ($curDate > $longest) {
                $longest = $curDate;
                $longestDate = $date;
            }
        }
        }
        return $longestDate;
    }

    function getSmallestDate($date_array){
        $estimates = $date_array;
        
        $smallestDate = "";
        if(is_array($estimates) && !empty($estimates)){
        $smallest = strtotime($estimates[0]);
        $smallestDate = $estimates[0];
        foreach($estimates as $key => $date){
            if(!$date) continue;

            $curDate = strtotime($date);
            if ($curDate < $smallest) {
                $smallest = $curDate;
                $smallestDate = $date;
            }
        }
        }
        return $smallestDate;
    }

    function message(){
        $template = $this->getMessageTemplate();
        $msg = $this->messageMaker($template);
        return $msg;
    }

    function messageMaker($template){
        $find = array('{date}','{days}','{min_date}','{min_days}','{max_date}','{max_days');
        $replace = array(
            $this->formatedDate($this->estimate), 
            $this->getEstimateDays(),
            $this->formatedDate($this->getMinDate()),
            $this->formatedDate($this->getMinDays()),
            $this->formatedDate($this->getMaxDate()),
            $this->formatedDate($this->getMaxDays())
        );
        $msg = str_replace($find, $replace, $template);
        return $msg;
    }

    function formatedDate($date){
        if(empty($date)) return null;

        return date_i18n($this->date_format, strtotime($date));
    }

    function getMessageTemplate(){
        if(!empty($this->range) && $this->min_date != $this->max_date){
            $msg_template = Pi_Edd_Product_Rule::getMessage('pi_overall_estimate_range_text','Order estimated delivery date {min_date} - {max_date}');
        }else{
            $msg_template = Pi_Edd_Product_Rule::getMessage('pi_overall_estimate_text','Order estimated delivery date {date}');
        }
        return $msg_template;
    }

    function getMessage(){
        return $this->msg;
    }

    function getEstimateDate(){
        return $this->estimate;
    }

    function getEstimateDays(){
        return Pi_Edd_Message_Engine::daysAwayFromToday($this->estimate);
    }

    function getMinDate(){
        return $this->min_date;
    }

    function getMaxDate(){
        return $this->max_date;
    }

    function getMinDays(){
        return Pi_Edd_Message_Engine::daysAwayFromToday($this->min_date);
    }

    function getMaxDays(){
        return Pi_Edd_Message_Engine::daysAwayFromToday($this->max_date);
    }
}