<?php

class Pi_Edd_Product_Controller{

    protected $rule = array(
        'single_page_position' => 'woocommerce_before_add_to_cart_button',
        'product_loop_position' => 'woocommerce_after_shop_loop_item_title',
        'show_range'    => false,
    );

    function __construct(){
        $this->setProductPagePosition();
        $this->setProductLoopPosition();
        $this->setSingleOrRange();
    

        add_action( 'wp_enqueue_scripts', array($this,'enqueue_scripts') );

        if($this->showOnSinglePage()){
        add_action($this->rule['single_page_position'], array($this,'estimateOnProductPage'));
        }

        if($this->showOnLoopPage()){
        add_action($this->rule['product_loop_position'], array($this,'estimateOnLoopPage'));
        }

        if($this->showOnCartPage()){
        add_action('woocommerce_after_cart_item_name', array($this,'estimateOnCartPage'),10,2);
        }

        if($this->showOnCheckoutPage()){
        add_filter('woocommerce_checkout_cart_item_quantity', array($this,'estimateOnCheckoutPage'),10,3);
        }

        if($this->showOverAllOrderEstimate()){
        add_action('woocommerce_review_order_after_shipping', array($this,'overAllOrderEstimate'));
        }

        if($this->showOverAllOrderEstimateOnCart()){
        add_action('woocommerce_after_cart_contents', array($this,'overAllOrderEstimateAsNotice'));
        }

        /** store estimate of each item in order */
        if($this->addEstimateInEachItemOfOrder()){
        add_action( 'woocommerce_checkout_create_order_line_item', array($this, 'addEstimateInOrderMeta'), 10, 4 );
        }

        /** modify how meta key are shown on the order detail page email and stored order */
        add_filter( 'woocommerce_order_item_get_formatted_meta_data', array($this,'changeItemMetaKeys'), 20, 2 );
        

        $this->updateOrderMetaWithOverAllEstimate();
    }

    function updateOrderMetaWithOverAllEstimate(){
		/* Update order meta data */
        add_action( 'woocommerce_checkout_update_order_meta', array($this,'updateOrderMeta') );
		
		//Display field value on the order edit page
        add_action( 'woocommerce_admin_order_data_after_shipping_address', array($this,'showOrderMeta'), 10, 1 );
        
        if($this->overallEstimateInOrderSuccessPage()){
		// Displays order meta on order detail page on front end
        add_action( 'woocommerce_order_details_after_order_table_items', array($this,'showOrderMeta'), 10, 1 );
        }
        
        if($this->overallEstimateInOrderEmail()){
		 //include the custom order meta to woocommerce mail
         add_action( "woocommerce_email_after_order_table", array($this,"showOrderMeta"), 10, 1);
        }
         
        
    }

    function updateOrderMeta($order_id){
		$order = wc_get_order( $order_id );
        $items = $order->get_items();
        $order_obj = new Pi_Edd_Order_Estimate($items);
        $msg = $order_obj->getMessage();
        $estimate = $order_obj->getEstimateDate();
        $estimate_days = $order_obj->getEstimateDays();

        $min_date = $order_obj->getMinDate();
        $min_days = $order_obj->getMinDays();

        $max_date = $order_obj->getMaxDate();
        $max_days = $order_obj->getMaxDays();

        update_post_meta( $order_id, 'pi_overall_estimate_min_date', sanitize_text_field( $min_date ) );
        update_post_meta( $order_id, 'pi_overall_estimate_min_days', sanitize_text_field( $min_days ) );
        update_post_meta( $order_id, 'pi_overall_estimate_max_date', sanitize_text_field( $max_date ) );
        update_post_meta( $order_id, 'pi_overall_estimate_max_days', sanitize_text_field( $max_days ) );

        update_post_meta( $order_id, 'pi_overall_estimate_date', sanitize_text_field( $estimate ) );
        update_post_meta( $order_id, 'pi_overall_estimate_days', sanitize_text_field( $estimate_days ) );
    }
    
    function showOrderMeta($order){
        $order_id = version_compare( WC_VERSION, '3.0.0', '<' ) ? $order->id : $order->get_id();
        
        
        $overall_estimate_msg = get_post_meta( $order_id, 'pi_overall_estimate', true );
        /** Old way of storing date with string */
        if(!empty($overall_estimate_msg)){
        echo '<p class="pi-overall-estimate"><strong>'.$overall_estimate_msg.'</strong></p>';
        }else{

            /** the above will be used for the old orders that stored the estimate as string
             * in "pi_overall_estimate"
             * This loop will be used for the latest implement where we only store estimate date in Y/m/d format and estimate number of days in "pi_overall_estimate_date" and "pi_overall_estimate_days"
             */
            $message = Pi_Edd_Show_Estimate::overAllEstimate($order_id);
            echo '<p class="pi-overall-estimate"><strong>'.$message.'</strong></p>';
        }
        
    }
    
    function estimateOnProductPage(){
        global $product;
        $product_id = $product->get_id();
        $rule_obj = new Pi_Edd_Product_Rule($product_id);
        if($rule_obj->getEnableEstimateForThisProduct()){
            if($rule_obj->useVariablePreparationTime()){
                echo '<div id="pisol_variation_estimate">';
                echo '</div>';
            }else{
                
                $msg = $rule_obj->getCompiledMessageAsPerLocation('single'.$this->range);
                //print_r($rule_obj);
                Pi_Edd_Template_Engine::message('single'.$this->range, $msg);
            }
        }
    }

    function estimateOnLoopPage(){
        global $product;
        $product_id = $product->get_id();
        $rule_obj = new Pi_Edd_Product_Rule($product_id);
        if($rule_obj->getEnableEstimateForThisProduct()){
        if($rule_obj->useVariablePreparationTime()){
            //Pi_Edd_Template_Engine::message('loop',"");
        }else{
            $msg = $rule_obj->getCompiledMessageAsPerLocation('loop'.$this->range);
            Pi_Edd_Template_Engine::message('loop'.$this->range, $msg);
        }
        }
    }

    function estimateOnCartPage($cart_item, $cart_item_key){
       
        $product_id = $cart_item['product_id'];
        $rule_obj = new Pi_Edd_Product_Rule($product_id, $cart_item['quantity']);
        if($rule_obj->getEnableEstimateForThisProduct()){
        if($rule_obj->useVariablePreparationTime()){
            $msg = $rule_obj->getCompiledMessageAsPerLocation('cart'.$this->range, $cart_item['variation_id']);
            echo '<br>';
            Pi_Edd_Template_Engine::message('cart'.$this->range, $msg);
        }else{
            $msg = $rule_obj->getCompiledMessageAsPerLocation('cart'.$this->range);
            echo '<br>';
            Pi_Edd_Template_Engine::message('cart'.$this->range, $msg);
        }
        }
    }

    function addEstimateInOrderMeta($item, $cart_item_key, $values, $order){
        $product_id = $item->get_product_id();
        $rule_obj = new Pi_Edd_Product_Rule($product_id, $item['quantity']);
        if($rule_obj->getEnableEstimateForThisProduct()){
            if($rule_obj->useVariablePreparationTime()){
                $msg = $rule_obj->getCompiledMessageAsPerLocation('cart'.$this->range, $values['variation_id']);

                $min_estimate_date = $rule_obj->getMinEstimateDate($values['variation_id']);
                $max_estimate_date = $rule_obj->getMaxEstimateDate($values['variation_id']);

                $min_estimate_days = Pi_Edd_Message_Engine::daysAwayFromToday($min_estimate_date);
                $max_estimate_days = Pi_Edd_Message_Engine::daysAwayFromToday($max_estimate_date);

               
            }else{
                $msg = $rule_obj->getCompiledMessageAsPerLocation('cart'.$this->range);
                
                $min_estimate_date = $rule_obj->getMinEstimateDate();
                $max_estimate_date = $rule_obj->getMaxEstimateDate();

                $min_estimate_days = Pi_Edd_Message_Engine::daysAwayFromToday($min_estimate_date);
                $max_estimate_days = Pi_Edd_Message_Engine::daysAwayFromToday($max_estimate_date);
            }

            $item->add_meta_data("pi_item_min_date",$min_estimate_date);
            $item->add_meta_data("pi_item_max_date",$max_estimate_date);
            $item->add_meta_data("pi_item_min_days",$min_estimate_days);
            $item->add_meta_data("pi_item_max_days",$max_estimate_days);
            
            $item->add_meta_data("pi_item_estimate_msg",$msg);
        }
    }

    function changeItemMetaKeys($meta_data, $item){
        $hide_keys = array('pi_item_min_date', 'pi_item_max_date', 'pi_item_min_days', 'pi_item_max_days');
        foreach($meta_data as $key => $data){

            if(in_array($data->key, $hide_keys)){
                unset($meta_data[$key]);
            }
            
            if($data->key === 'pi_item_estimate_msg'){
                $meta_data[$key]->display_key = "&#128652;";
            }
            
        }
        return $meta_data;
    }

    function estimateOnCheckoutPage($link_text, $cart_item, $cart_item_key){
        $product_id = $cart_item['product_id'];
        $rule_obj = new Pi_Edd_Product_Rule($product_id, $cart_item['quantity']);
        if($rule_obj->getEnableEstimateForThisProduct()){
        if($rule_obj->useVariablePreparationTime()){
            $msg = $rule_obj->getCompiledMessageAsPerLocation('cart'.$this->range, $cart_item['variation_id']);
            return $link_text.'<br>'.Pi_Edd_Template_Engine::message('cart'.$this->range, $msg, true);
        }else{
            $msg = $rule_obj->getCompiledMessageAsPerLocation('cart'.$this->range);
            echo '<br>';
            return $link_text.'<br>'.Pi_Edd_Template_Engine::message('cart'.$this->range, $msg, true);
        }
        }
        return $link_text;
    }

    function setProductPagePosition(){
        $position = get_option('pi_product_page_position','woocommerce_before_add_to_cart_button');
        $show = get_option('pi_show_product_page',1);
        if($show){
            $this->rule['single_page_position'] = $position;
        }else{
            $this->rule['single_page_position'] = false;
        }
    }

    function setProductLoopPosition(){
        $position = get_option('pi_loop_page_position','woocommerce_after_shop_loop_item_title');
        $show = get_option('pi_show_product_loop_page',1);
        if($show){
            $this->rule['product_loop_position'] = $position;
        }else{
            $this->rule['product_loop_position'] = false;
        }
    }

    function setSingleOrRange(){
        $range = get_option('pi_general_range',0);
        if($range == 1){
            $this->rule['show_range'] = true;
        }else{
            $this->rule['show_range'] = false;
        }
        $this->range = $this->showRange() ? "_range" : "";

    }

    function showRange(){
        return $this->rule['show_range'];
    }

    function getProductPagePosition(){
		return $this->rule['single_page_position'];
    }

    function getProductLoopPosition(){
		return $this->rule['product_loop_position'];
    }

    function enqueue_scripts(){
        wp_enqueue_script('pi-edd-script', plugin_dir_url( __FILE__ ) . 'js/pi-edd-public.js', array( 'jquery' ), "", false );

        if( is_product() ){
            global $post;
            $product_id = $post->ID;
            $rule_obj = new Pi_Edd_Product_Rule($product_id);
            if($rule_obj->getEnableEstimateForThisProduct()){
                $js = $rule_obj->getCompiledMessageAsPerLocation('single'.$this->range);
                if(!empty($js)){
                wp_register_script( 'pi-edd-variable-product', '', array('jquery') );
                wp_enqueue_script( 'pi-edd-variable-product'  );
                wp_localize_script( 'pi-edd-variable-product', 'variation_estimate_msg',  $js);
                }
            }
        }
    }

    function overAllOrderEstimateAsNotice(){
        ?>
            <tr id="pi-overall-estimate-cart">
				<td colspan="6" class="actions">
					<?php echo $this->overAllOrderEstimate(true); ?>
				</td>
			</tr>
        <?php
    }

    function overAllOrderEstimate($message = false){
        $cart_items = WC()->cart->get_cart_contents();
        $order_obj = new Pi_Edd_Order_Estimate($cart_items);
        $msg = $order_obj->getMessage();
        if($msg !=""){
            if($message){
                return ($msg);
            }else{
                echo '<tr class="pisol-edd-overall-order-estimate-row"><td colspan="2">';
                echo '<strong class="pisol-edd-overall-order-estimate">'.$msg.'</strong>';
                echo '</td></tr>';
            }
        }
    }

    function showOnSinglePage(){
        $option = get_option('pi_show_product_page', 1);
        if($option != 0){
            return true;
        }
        return false;
    }

    function showOnLoopPage(){
        $option = get_option('pi_show_product_loop_page', 1);
        if($option != 0){
            return true;
        }
        return false;
    }

    function showOnCartPage(){
        $option = get_option('pi_show_cart_page', 1);
        if($option != 0){
            return true;
        }
        return false;
    }

    function showOnCheckoutPage(){
        $option = get_option('pi_show_checkout_page', 1);
        if($option != 0){
            return true;
        }
        return false;
    }

    function showOverAllOrderEstimate(){
        $option = get_option('pi_edd_cart_page_show_overall_estimate', 1);
        if($option != 0){
            return true;
        }
        return false;
    }

    function showOverAllOrderEstimateOnCart(){
        $option = get_option('pi_edd_show_overall_estimate_on_cart_page', 1);
        if($option != 0){
            return true;
        }
        return false;
    }

    function addEstimateInEachItemOfOrder(){
        $option = get_option('pi_edd_cart_page_show_single_estimate', 1);
        if($option != 0){
            return true;
        }
        return false;
    }

    function overallEstimateInOrderEmail(){
        $option = get_option('pi_edd_show_overall_estimate_in_email', 1);
        if($option != 0){
            return true;
        }
        return false;
    }

    function overallEstimateInOrderSuccessPage(){
        $option = get_option('pi_edd_show_overall_estimate_in_order_success_page', 1);
        if($option != 0){
            return true;
        }
        return false;
    }

}


add_action('wp_loaded',function(){
    if(get_option('pi_edd_enable_estimate',1) != 0){
        new Pi_Edd_Product_Controller();
    }
});